@@ -1,7 +1,10 @@
+from os import getcwd
 import logging
-import subprocess
 
-from vdt.versionplugin.debianize.shared import parse_version_extra_args
+from vdt.versionplugin.debianize.shared import (
+    parse_version_extra_args,
+    PackageBuilder
+)
 
 log = logging.getLogger('vdt.versionplugin.debianize.package')
 
@@ -12,17 +15,13 @@ def build_package(version):
     """
     args, extra_args = parse_version_extra_args(version.extra_args)
 
-    includes = []
-    if args.include:
-        for include in args.include:
-            includes.append('-i')
-            includes.append(include)
-    
     log.debug("Building version {0} with debianize.".format(version))
     with version.checkout_tag:
-        cmd = ['debianize.sh'] + includes + ['--version=%s' % version, '--python-install-lib=/usr/lib/python2.7/dist-packages/'] + extra_args
-        log.debug("Running command {0}".format(" ".join(cmd)))
-        log.debug(subprocess.check_output(cmd))
+        deb_dir = getcwd()
+        # use a package build class which has all kinds of hooks.
+        builder = PackageBuilder(version, args, extra_args, deb_dir)
+        builder.build_package_and_dependencies()
+        return builder.exit_code
 
     return 0
 
